#
# spec file for package kernel-firmware-nvidia-gspx-G06
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define simpletest 0

%ifarch x86_64
%define arch x86_64
%else
%define arch aarch64
%endif

%if %{undefined _firmwaredir}
%define _firmwaredir /lib/firmware
%endif

Name:           kernel-firmware-nvidia-gspx-G06
URL:            https://www.nvidia.com/en-us/drivers/unix/
Version:        550.90.07
Release:        1.0.2.1.sr20240429
Summary:        Kernel firmware file for open NVIDIA kernel module driver G06
License:        GPL-2.0-only AND SUSE-Firmware AND GPL-2.0-or-later AND MIT
Group:          System/Kernel
Source0:        http://download.nvidia.com/XFree86/Linux-x86_64/%{version}/NVIDIA-Linux-x86_64-%{version}.run
Source1:        http://download.nvidia.com/XFree86/Linux-aarch64/%{version}/NVIDIA-Linux-aarch64-%{version}.run
NoSource:       0
NoSource:       1
%if 0%{simpletest} == 1
Source2:        %{name}-rpmlintrc
%else
Provides:       multiversion(kernel)
%endif
ExclusiveArch:  x86_64 aarch64
Obsoletes:      kernel-firmware-nvidia-gsp-G06 = 535.86.05

%description
This package contains the versioned kernel firmware file "gsp.bin" for
the OpenSource NVIDIA kernel module driver G06.

%prep
sh %{_sourcedir}/NVIDIA-Linux-%{arch}-%{version}.run -x

%build

%install
mkdir -p %{buildroot}%{_firmwaredir}/nvidia/%{version}
install -m 644 NVIDIA-Linux-%{arch}-%{version}/firmware/{gsp_ga10x.bin,gsp_tu10x.bin} \
  %{buildroot}%{_firmwaredir}/nvidia/%{version}
%if 0%{simpletest} == 1
mkdir -p %{buildroot}/usr/lib/%{name}
install -m 755 ./NVIDIA-Linux-%{arch}-%{version}/nvidia-smi %{buildroot}/usr/lib/%{name}
install -m 755 ./NVIDIA-Linux-%{arch}-%{version}/libnvidia-ml.so.%{version} %{buildroot}/usr/lib/%{name}
ln -snf libnvidia-ml.so.%{version} %{buildroot}/usr/lib/%{name}/libnvidia-ml.so.1
%endif

%if 0%{simpletest} == 1
%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%dir %{_firmwaredir}/nvidia
%dir %{_firmwaredir}/nvidia/%{version}
%{_firmwaredir}/nvidia/%{version}/gsp_ga10x.bin
%{_firmwaredir}/nvidia/%{version}/gsp_tu10x.bin
%if 0%{simpletest} == 1
%dir /usr/lib/%{name}
/usr/lib/%{name}/nvidia-smi
/usr/lib/%{name}/libnvidia-ml.so.%{version}
/usr/lib/%{name}/libnvidia-ml.so.1
%endif

%changelog
* Tue Jun  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Security Update 550.90.07
  * addresses boo#1223356 [CVE-2024-0090, CVE-2024-0091, CVE-2024-0092]
* Mon Apr 29 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to 550.78
  * addresses boo#1223454
* Wed Apr 17 2024 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 550.76
  * addresses boo#1222972
* Wed Mar 20 2024 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 550.67
* Sat Feb 24 2024 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 550.54.14
* Thu Nov 23 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 545.29.06
* Mon Nov 13 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 545.29.02
* Wed Nov  1 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 535.129.03
* Fri Sep 22 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 535.113.01
* Mon Aug 28 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 535.104.05
* Wed Jul 26 2023 Stefan Dirsch <sndirsch@suse.com>
- Obsoletes conflicting kernel-firmware-nvidia-gsp-G06 = 535.86.05
  (boo#1212724)
- minor cleanup in specfile
* Wed Jul 26 2023 Stefan Dirsch <sndirsch@suse.com>
- remove conflicts from previous change again, since this likely
  would break QA test for sle again ...
* Wed Jul 26 2023 Stefan Dirsch <sndirsch@suse.com>
- added conflicts to kernel-firmware-nvidia-gsp-G06 package
* Tue Jul 25 2023 Stefan Dirsch <sndirsch@suse.com>
- one-time rename to kernel-firmware-nvidia-gspx-G06 to workaround
  multiversioned package update (boo#1212724)
* Wed Jul 19 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 535.86.05
* Thu Jun 15 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 535.54.03
  * gsp_ad10x.bin has been renamed to gsp_ga10x.bin
* Wed May 31 2023 Stefan Dirsch <sndirsch@suse.com>
- make package multiversion capable
  * no longer package libnvidia-ml and nvidia-smi
  * added "Provides: multiversion(kernel)"
* Tue May  9 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.116.04
* Tue Apr 25 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.116.03
* Thu Mar 30 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.105.17
* Wed Feb  8 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.89.02
* Thu Jan 19 2023 Stefan Dirsch <sndirsch@suse.com>
- removed old firmware
* Thu Jan 19 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.85.05
* Thu Jan 19 2023 Callum Farmer <gmbr3@opensuse.org>
- Use _firmwaredir
* Wed Jan 18 2023 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile constructs
* Wed Jan 18 2023 Stefan Dirsch <sndirsch@suse.com>
- renamed rpmlintrc to %%{name}-rpmlintrc
* Wed Jan 18 2023 Stefan Dirsch <sndirsch@suse.com>
- implements jsc#PED-2658
* Mon Jan  9 2023 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.78.01
* Wed Jan  4 2023 Stefan Dirsch <sndirsch@suse.com>
- renamed package to kernel-firmware-nvidia-gsp-G06 due to package
  redesign
* Mon Nov 28 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.60.11
* Fri Nov 11 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 525.53
* Tue Oct 18 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 515.76
* Wed Aug  3 2022 Stefan Dirsch <sndirsch@suse.com>
- re-enabled simpletest (nvidia-smi); moved nvidia-smi and
  required libnvidia-ml to /usr/lib/kernel-firmware-nvidia-gsp to
  avoid conflicts with program/lib in nvidia-computeG06; run it with
  LD_LIBRARY_PATH=/usr/lib/kernel-firmware-nvidia-gsp \
    /usr/lib/kernel-firmware-nvidia-gsp/nvidia-smi
* Mon Aug  1 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 515.65.01
* Thu Jun 30 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 515.57
- no longer enable installation of simpletest (nvidia-smi) in
  order to avoid file conflicts with nvidia-computeG06
* Tue May 31 2022 Stefan Dirsch <sndirsch@suse.com>
- fixed URL in specfile
* Tue May 31 2022 Stefan Dirsch <sndirsch@suse.com>
- update firmware to version 515.48.07
* Wed May 25 2022 Stefan Dirsch <sndirsch@suse.com>
- fixed build on aarch64
* Fri May 20 2022 Stefan Dirsch <sndirsch@suse.com>
- fixed another warning
- added aarch shell script archive
* Thu May 19 2022 Stefan Dirsch <sndirsch@suse.com>
- created package
